@@ -1,4 +1,4 @@
-from .req import get
+from req import get
 
 def search(tags, limit=None):
     return get(tags, limit)
